WebSocketRSocketResponder class

Inheritance
Implemented types

Constructors

WebSocketRSocketResponder(Uri uri, HttpServer httpServer, SocketAcceptor socketAcceptor)

Properties

hashCode → int
The hash code for this object.
no setterinherited
httpServer ↔ HttpServer
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socketAcceptor ↔ SocketAcceptor
getter/setter pairinherited
uri ↔ Uri
getter/setter pairinherited

Methods

accept() → void
close() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
receiveConnection(DuplexConnection duplexConn) → Future<void>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited