DuplexConnection class abstract

Implemented types
Implementers

Constructors

DuplexConnection()

Properties

closeHandler ↔ CloseHandler?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
receiveHandler ↔ TcpChunkHandler?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

availability() → double
override
close() → void
inherited
init() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
write(Uint8List chunk) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited