TcpDuplexConnection class

Inheritance

Constructors

TcpDuplexConnection(Socket socket)

Properties

closed ↔ bool
getter/setter pair
closeHandler ↔ CloseHandler?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
receiveHandler ↔ TcpChunkHandler?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socket ↔ Socket
getter/setter pair

Methods

availability() → double
inherited
close() → void
override
init() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
write(Uint8List chunk) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited