FrameCodec class

Constructors

FrameCodec()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encodeCancelFrame(int streamId) → Uint8List
encodeChannelFrame(int streamId, int initialRequestN, Payload payload) → Uint8List
encodeErrorFrame(int streamId, int code, String message) → Uint8List
encodeFireAndForgetFrame(int streamId, Payload payload) → Uint8List
encodeKeepAlive(bool respond, int lastPosition) → Uint8List
encodeMetadataFrame(int streamId, Payload payload) → Uint8List
encodePayloadFrame(int streamId, bool completed, Payload? payload) → Uint8List
encodeRequestResponseFrame(int streamId, Payload payload) → Uint8List
encodeRequestStreamFrame(int streamId, int initialRequestN, Payload payload) → Uint8List
encodeSetupFrame(int keepAliveInterval, int keepAliveMaxLifetime, String metadataMimeType, String dataMimeType, Payload? setupPayload) → Uint8List