RSocketHeader class

Properties

flags ↔ int
getter/setter pair
frameLength ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metaPresent ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamId ↔ int
getter/setter pair
type ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited