RSocketByteBuffer class

Constructors

RSocketByteBuffer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

autoGrow() → void
capacity() → int
insertBytes(List<int> bytes) → void
insertI24(int value) → void
isReadable() → bool
isWritable() → bool
maxReadableBytes() → int
maxWritableBytes() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readBytes(int len) → List<int>
readI16() → int?
readI24() → int?
readI32() → int?
readI64() → int?
readI8() → int?
readUint8List(int len) → Uint8List
resetReaderIndex() → void
resetWriterIndex() → void
rewind() → void
toString() → String
A string representation of this object.
inherited
toUint8Array() → Uint8List
writeBytes(List<int> bytes) → void
writeI16(int value) → void
writeI24(int value) → void
writeI32(int value) → void
writeI64(int value) → void
writeI8(int value) → void
writeUint8List(Uint8List data) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited