AuthMetadata class

Inheritance

Constructors

AuthMetadata(int authTypeId, Uint8List authData)

Properties

authData ↔ Uint8List
getter/setter pair
authTypeId ↔ int
getter/setter pair
content ↔ Uint8List?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pairinherited
mimeType ↔ String?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

jwt(String jwtToken) → AuthMetadata
simple(String username, String password) → AuthMetadata