CompositeMetadata class

Inheritance

Constructors

CompositeMetadata(RSocketByteBuffer buffer)

Properties

buffer ↔ RSocketByteBuffer
getter/setter pair
first → MetadataEntry
The first element.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<MetadataEntry>
A new Iterator that allows iterating the elements of this Iterable.
no setteroverride
last → MetadataEntry
The last element.
no setterinherited
length → int
The number of elements in this Iterable.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → MetadataEntry
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

addExplicitMimeType(String? mimeType, Uint8List? content) → void
addMetadata(MetadataEntry metadata) → void
addWellKnownMimeType(int typeId, Uint8List content) → void
any(bool test(MetadataEntry element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) → MetadataEntry
Returns the indexth element.
inherited
every(bool test(MetadataEntry element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(MetadataEntry element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(MetadataEntry element), {MetadataEntry orElse()?}) → MetadataEntry
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, MetadataEntry element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<MetadataEntry> other) → Iterable<MetadataEntry>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(MetadataEntry metadata)) → void
Invokes action on each element of this iterable in iteration order.
inherited
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(MetadataEntry element), {MetadataEntry orElse()?}) → MetadataEntry
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(MetadataEntry e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseEntries() → Iterable<MetadataEntry>
reduce(MetadataEntry combine(MetadataEntry value, MetadataEntry element)) → MetadataEntry
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
singleWhere(bool test(MetadataEntry element), {MetadataEntry orElse()?}) → MetadataEntry
The single element that satisfies test.
inherited
skip(int count) → Iterable<MetadataEntry>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(MetadataEntry element)) → Iterable<MetadataEntry>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<MetadataEntry>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(MetadataEntry element)) → Iterable<MetadataEntry>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<MetadataEntry>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<MetadataEntry>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
toUint8Array() → Uint8List
where(bool test(MetadataEntry element)) → Iterable<MetadataEntry>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited