RoutingMetadata class

Inheritance

Constructors

RoutingMetadata(String routingKey, List<String> extraTags)

Properties

content ↔ Uint8List?
getter/setter pairinherited
extraTags ↔ List<String>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pairinherited
mimeType ↔ String?
getter/setter pairinherited
routingKey ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags ↔ List<String>
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromEntry(MetadataEntry entry) → RoutingMetadata
override