ConnectionSetupPayload class

Inheritance

Constructors

ConnectionSetupPayload()

Properties

data ↔ Uint8List?
getter/setter pairinherited
dataMimeType ↔ String
getter/setter pair
flags ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keepAliveInterval ↔ int
getter/setter pair
keepAliveMaxLifetime ↔ int
getter/setter pair
metadata ↔ Uint8List?
getter/setter pairinherited
metadataMimeType ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDataUtf8() → String?
inherited
getMetadataUtf8() → String?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited