RSocketServiceRouter class

Constructors

RSocketServiceRouter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceMirrors ↔ Map<String, InstanceMirror>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceInstances ↔ Map<String, dynamic>
getter/setter pair

Methods

addService(dynamic serviceInstance) → void
invokeService(String serviceName, String method, dynamic params) → dynamic
isServiceAvailable(String serviceName) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited